#[non_exhaustive]pub enum MessageError {
Json(Error),
UnsupportedVersion(u8),
EmptyQuery,
MaxResultsOutOfRange(u32),
}Expand description
Errors that can occur when encoding or decoding a NERVE message payload.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Json(Error)
The JSON payload could not be serialized or deserialized.
UnsupportedVersion(u8)
The v field in the payload does not equal MESSAGE_VERSION.
EmptyQuery
The query field is an empty string.
MaxResultsOutOfRange(u32)
The max_results field is outside 1..=MAX_RESULTS.